@@ -291,7 +291,7 @@ const char* VerifyException::m_error_strings[] =
     "no checksum was supplied at the end of the file",
     "one of the internal frame structures does not pass its own consitancy check",
     "the file is missing the FrEndOfFile structure required by the frame specification.",
-    "One or more channels have a non-zero dataValid field.",
+    "One or more channels has a non-zero dataValid field.",
     "One or more pieces of the filename meta data is invalid.",
     "One or more channel names have been duplicated within a frame."
   };
@@ -907,7 +907,7 @@ operator()( IFrameStream& Stream,
 		    << std::setfill('0')
 		    << dv
 		    << " channel: " << name
-		    << std::endl;
+		  ;
 		thrower( VerifyException( VerifyException::DATA_INVALID,
 					  msg.str( ) ) );
 	      }
@@ -1063,6 +1063,8 @@ operator()( IFrameStream& Stream,
 	       && ( CheckDataValidAll( ) ) )
 	  {
 	    dataValidAll
+	      << std::endl
+	      << "\t\t"
 	      << E.what( )
 	      << " in frame: " << frame_offset
 	      ;
