@@ -23,6 +23,12 @@ using FrameCPP::Common::Description;
 using FrameCPP::Common::FrameSpec;
 using FrameCPP::Common::IStream;
 
+#if HAVE_TEMPLATE_MOVE
+#define MOVE_RET(a) ( std::move( a ) )
+#else /* HAVE_TEMPLATE_MOVE */
+#define MOVE_RET(a) ( a )
+#endif /* HAVE_TEMPLATE_MOVE */
+
 //=======================================================================
 // Static
 //=======================================================================
@@ -351,7 +357,14 @@ namespace FrameCPP
 	break;
       }
 
-      return retval;
+#if __clang__ && ( (__clang_major__ > 7) || ( (__clang_major__ == 7) && (__clang_minor__ >= 3 ) ) )
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wpessimizing-move"
+#endif /* __clang__ */
+      return MOVE_RET( retval );
+#if __clang__ && ( (__clang_major__ > 7) || ( (__clang_major__ == 7) && (__clang_minor__ >= 3 ) ) )
+#pragma clang diagnostic pop
+#endif /* __clang__ */
     }
 
     bool FrProcData::
@@ -528,7 +541,14 @@ namespace FrameCPP
       //---------------------------------------------------------------------
       // Return the new FrProcData
       //---------------------------------------------------------------------
-      return retval;
+#if __clang__ && ( (__clang_major__ > 7) || ( (__clang_major__ == 7) && (__clang_minor__ >= 3 ) ) )
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wpessimizing-move"
+#endif /* __clang__ */
+      return MOVE_RET( retval );
+#if __clang__ && ( (__clang_major__ > 7) || ( (__clang_major__ == 7) && (__clang_minor__ >= 3 ) ) )
+#pragma clang diagnostic pop
+#endif /* __clang__ */
     }
   } // namespace - Version_6
 } // namespace - FrameCPP
