@@ -1,5 +1,6 @@
 #include <framecpp_config.h>
 
+#include "ldastoolsal/Memory.hh"
 #include "ldastoolsal/regex.hh"
 #include "ldastoolsal/regexmatch.hh"
 
@@ -45,7 +46,7 @@ namespace FrameCPP
 	return;
       }
 
-      std::auto_ptr< Previous::FrTOC > toc_previous( new Previous::FrTOC( Source ) );
+      std::unique_ptr< Previous::FrTOC > toc_previous( new Previous::FrTOC( Source ) );
 
       *this = *toc_previous;
     }
