@@ -660,8 +660,14 @@ test_small_frames( )
 		  obuf->str( ).length( ) );
       fstr.close( );
 #endif /* 0 */
+      char cfilename[4096];
+
+      ::strcpy( cfilename, filename.str( ).c_str( ) );
+
       Exec cmd( "./framecpp_verify",
-		filename.str( ).c_str( ),
+		"--verbose",
+		"--verbose",
+		cfilename,
 		Exec::COMMAND_END );
       cmd.Spawn( );
       Test.Check( cmd.ExitCode( ) == 0 )
@@ -669,6 +675,16 @@ test_small_frames( )
 	<< filename.str( )
 	<< std::endl
 	;
+      if ( cmd.ExitCode( ) != 0 )
+      {
+	Test.Message( 10 )
+	  << "StdOut: " << cmd.Stdout( )
+	  << std::endl
+	  << "StdErr:" << cmd.Stderr( )
+	  << std::endl
+	  ;
+      }
+
     }
   }
 }
